@@ -3,13 +3,15 @@ Main interface for workdocs service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.workdocs import WorkDocsClient
+    from mypy_boto3_workdocs import WorkDocsClient
 
     session = boto3.Session()
 
     client: WorkDocsClient = boto3.client("workdocs")
     session_client: WorkDocsClient = session.client("workdocs")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
