@@ -3,8 +3,11 @@ Main interface for workdocs service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.workdocs import (
+
+    from mypy_boto3_workdocs import WorkDocsClient
+    from mypy_boto3_workdocs import (
         DescribeActivitiesPaginator,
         DescribeCommentsPaginator,
         DescribeDocumentVersionsPaginator,
@@ -27,6 +30,7 @@ Usage::
     describe_resource_permissions_paginator: DescribeResourcePermissionsPaginator = client.get_paginator("describe_resource_permissions")
     describe_root_folders_paginator: DescribeRootFoldersPaginator = client.get_paginator("describe_root_folders")
     describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
