@@ -3,9 +3,11 @@ Main interface for workdocs service type definitions.
 
 Usage::
 
-    from mypy_boto3.workdocs.type_defs import ActivityTypeDef
+    ```python
+    from mypy_boto3_workdocs.type_defs import ActivityTypeDef
 
     data: ActivityTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
